/*
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////


						MCP4922 Serial Interface
	

			bit 15
			&=A/B	: DAC-A or DAC-B selection bit

				1: DAC-B
				0: DAC-A


			bit 14
			BUF		: VREF input buffer control bit
		
				1: Buffered
				0: Unbuffered


			bit 13
			&=GA		: Output amplifier gain control bit

				1: Gain disabled, Vout =	Vref x (D/4096)
				0: Gain enabled,  Vout = 2x	Vref x (D/4095)


			bit 12
			SHDN	: 

				1: Output power down control bit
				0: Output buffer disabled, high impendance


			bit 11-0
			D11 - D0 : 
	
				DAC data bits which sets the output value.
				Contains a value between 0 and 4095.


//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////	
*/

	// Select: CH-A, unbuffered, gain disabled, output enabled
#define CHA_Mask 0x30;	
	
	// Select: CH-B, unbuffered, gain disabled, output enabled
#define	CHB_Mask 0xB0;	
	


void Init_DAC_CHA()
	
 {
	CHA_DATA = 0;
	Load_DAC_CHA();
 }


 
void Init_DAC_CHB()
	
 {
	CHB_DATA = 0;
	Load_DAC_CHB();
 }



void Load_DAC_CHA()
		
 {
	uint8_t DataH;
	uint8_t	DataL;	

	DataH = (uint8_t)(CHA_DATA >>8);
	DataL = (uint8_t)(CHA_DATA);
	
	DataH = DataH| CHA_Mask;

	PORTB &= ~(1<<DAC0_CS);

		SPDR = DataH;
				while(!(SPSR & (1<<SPIF)));
	
		SPDR = DataL;
				while(!(SPSR & (1<<SPIF)));

	PORTB |= (1<<DAC0_CS);

	PORTB &=~(1<<DAC0_LOAD);
	PORTB |= (1<<DAC0_LOAD);
 }
		

void Load_DAC_CHB()

 {
 	uint8_t DataH;
	uint8_t	DataL;	

	DataH = (uint8_t)(CHB_DATA >>8);
	DataL = (uint8_t)(CHB_DATA);
	
	DataH = DataH| CHB_Mask;

	PORTB &= ~(1<<DAC0_CS);

		SPDR = DataH;
				while(!(SPSR & (1<<SPIF)));
	
		SPDR = DataL;
				while(!(SPSR & (1<<SPIF)));

	PORTB |= (1<<DAC0_CS);

	PORTB &=~(1<<DAC0_LOAD);
	PORTB |= (1<<DAC0_LOAD);
 }
